summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--kconfiglib.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/kconfiglib.py b/kconfiglib.py
index fda4d0c..7ad76fd 100644
--- a/kconfiglib.py
+++ b/kconfiglib.py
@@ -1038,12 +1038,13 @@ class Kconfig(object):
'strerror', and 'filename' are available). Note that IOError can be
caught as OSError on Python 3.
- filename:
+ filename (default: None):
Path to load configuration from (a string). Respects $srctree if set
(see the class documentation).
- If 'filename' is None, the configuration file to load (if any) is
- calculated automatically, giving the behavior you'd usually want:
+ If 'filename' is None (the default), the configuration file to load
+ (if any) is calculated automatically, giving the behavior you'd
+ usually want:
1. If the KCONFIG_CONFIG environment variable is set, it gives the
path to the configuration file to load. Otherwise, ".config" is
@@ -1311,8 +1312,8 @@ class Kconfig(object):
filename (default: None):
Filename to save configuration to (a string).
- If None, the filename in the the environment variable KCONFIG_CONFIG
- is used if set, and ".config" otherwise. See
+ If None (the default), the filename in the the environment variable
+ KCONFIG_CONFIG is used if set, and ".config" otherwise. See
standard_config_filename().
header (default: "# Generated by Kconfiglib (https://github.com/ulfalizer/Kconfiglib)\n"):